@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -25,9 +25,7 @@ ImportAlarmJobInterface::ImportAlarmJobInterface(QObject *parent, Utils::StoredT
     initializeImportJob();
 }
 
-ImportAlarmJobInterface::~ImportAlarmJobInterface()
-{
-}
+ImportAlarmJobInterface::~ImportAlarmJobInterface() = default;
 
 void ImportAlarmJobInterface::start()
 {
@@ -68,6 +66,11 @@ QString ImportAlarmJobInterface::configLocation() const
     return installConfigLocation();
 }
 
+QString ImportAlarmJobInterface::applicationName() const
+{
+    return QStringLiteral("[Alarm]");
+}
+
 QString ImportAlarmJobInterface::installConfigLocation() const
 {
     return QStandardPaths::writableLocation(QStandardPaths::ConfigLocation) + QLatin1Char('/');
@@ -92,7 +95,7 @@ void ImportAlarmJobInterface::restoreConfig()
         }
     }
     restoreUiRcFile(QStringLiteral("kalarmui.rc"), QStringLiteral("kalarm"));
-    Q_EMIT info(i18n("Config restored."));
+    emitInfo(i18n("Config restored."));
     QTimer::singleShot(0, this, &ImportAlarmJobInterface::slotNextStep);
 }
 
@@ -108,7 +111,7 @@ void ImportAlarmJobInterface::importkalarmConfig(const KArchiveFile *kalarmFile,
 
 void ImportAlarmJobInterface::restoreResources()
 {
-    Q_EMIT info(i18n("Restore resources..."));
+    emitInfo(i18n("Restore resources..."));
     setProgressDialogLabel(i18n("Restore resources..."));
     increaseProgressDialog();
     QStringList listResource;
@@ -154,9 +157,9 @@ void ImportAlarmJobInterface::restoreResources()
                     if (!agentConfigFile.isEmpty()) {
                         const KArchiveEntry *akonadiAgentConfigEntry = mArchiveDirectory->entry(agentConfigFile);
                         if (akonadiAgentConfigEntry->isFile()) {
-                            const auto file = static_cast<const KArchiveFile *>(akonadiAgentConfigEntry);
-                            copyArchiveFileTo(file, copyToDirName);
-                            resourceName = file->name();
+                            const auto akonadiAgentConfigEntryFile = static_cast<const KArchiveFile *>(akonadiAgentConfigEntry);
+                            copyArchiveFileTo(akonadiAgentConfigEntryFile, copyToDirName);
+                            resourceName = akonadiAgentConfigEntryFile->name();
                             filename = Utils::akonadiAgentName(copyToDirName + QLatin1Char('/') + resourceName);
                         }
                     }
