@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -34,7 +34,7 @@ void ImportAddressbookJobInterfaceTest::importAddressbook()
     QFETCH(QString, testPath);
     QFETCH(Utils::StoredTypes, options);
 
-    auto *file = new TestImportFile(zipFilePath + testPath, this);
+    auto file = new TestImportFile(zipFilePath + testPath, this);
     file->setPathConfig(zipFilePath + testPath);
     file->setExtractPath(QDir::tempPath() + testPath);
     file->setExcludePath(Utils::addressbookPath());
