@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -17,9 +17,7 @@ BackupResourceFileJobBase::BackupResourceFileJobBase(QObject *parent)
 {
 }
 
-BackupResourceFileJobBase::~BackupResourceFileJobBase()
-{
-}
+BackupResourceFileJobBase::~BackupResourceFileJobBase() = default;
 
 void BackupResourceFileJobBase::storeResource(const QString &archivePath)
 {
