@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -131,8 +131,8 @@ void ExportMailJobInterfaceImpl::exportFilters()
         QTemporaryFile tmp;
         tmp.open();
         const QUrl url = QUrl::fromLocalFile(tmp.fileName());
-        MailCommon::FilterImporterExporter exportFilters;
-        exportFilters.exportFilters(lstFilter, url, true);
+        MailCommon::FilterImporterExporter mailCommonExportFilters;
+        mailCommonExportFilters.exportFilters(lstFilter, url, true);
         tmp.close();
         const bool fileAdded = archive()->addLocalFile(tmp.fileName(), Utils::configsPath() + QStringLiteral("filters"));
         if (fileAdded) {
