@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -15,10 +15,22 @@
 
 #ifdef WITH_KUSERFEEDBACK
 #include "userfeedback/userfeedbackmanager.h"
+#ifdef USE_KUSERFEEDBACK_QT6
+#include <KUserFeedbackQt6/FeedbackConfigWidget>
+#include <KUserFeedbackQt6/Provider>
+#else
 #include <KUserFeedback/FeedbackConfigWidget>
 #include <KUserFeedback/Provider>
 #endif
+#endif
 
+#include <KWindowConfig>
+#include <QWindow>
+
+namespace
+{
+static const char myPimDataExporterConfigureDialogGroupName[] = "PimDataExporterConfigureDialog";
+}
 PimDataExporterConfigureDialog::PimDataExporterConfigureDialog(QWidget *parent)
     : KPageDialog(parent)
     , mConfigureWidget(new PimDataExporterConfigureWidget(this))
@@ -33,7 +45,7 @@ PimDataExporterConfigureDialog::PimDataExporterConfigureDialog(QWidget *parent)
 
     layout->addWidget(mConfigureWidget);
 
-    auto *generalPageWidgetPage = new KPageWidgetItem(mConfigureWidget, i18n("General"));
+    auto generalPageWidgetPage = new KPageWidgetItem(mConfigureWidget, i18n("General"));
     generalPageWidgetPage->setIcon(QIcon::fromTheme(QStringLiteral("network-workgroup")));
     addPage(generalPageWidgetPage);
 
@@ -78,16 +90,16 @@ void PimDataExporterConfigureDialog::slotAccepted()
 
 void PimDataExporterConfigureDialog::readConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), "PimDataExporterConfigureDialog");
-    const QSize size = group.readEntry("Size", QSize(600, 400));
-    if (size.isValid()) {
-        resize(size);
-    }
+    create(); // ensure a window is created
+    windowHandle()->resize(QSize(600, 400));
+    KConfigGroup group(KSharedConfig::openStateConfig(), myPimDataExporterConfigureDialogGroupName);
+    KWindowConfig::restoreWindowSize(windowHandle(), group);
+    resize(windowHandle()->size()); // workaround for QTBUG-40584
 }
 
 void PimDataExporterConfigureDialog::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), "PimDataExporterConfigureDialog");
-    group.writeEntry("Size", size());
+    KConfigGroup group(KSharedConfig::openStateConfig(), myPimDataExporterConfigureDialogGroupName);
+    KWindowConfig::saveWindowSize(windowHandle(), group);
     group.sync();
 }
