@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -10,15 +10,23 @@
 #include <KConfigGroup>
 #include <KLocalizedString>
 #include <KSharedConfig>
+#include <KWindowConfig>
 #include <QCheckBox>
 #include <QDialogButtonBox>
 #include <QHBoxLayout>
 #include <QPushButton>
 #include <QVBoxLayout>
-
+#include <QWindow>
+namespace
+{
+static const char myConfigSelectionTypeDialogDialog[] = "SelectionTypeDialog";
+}
 SelectionTypeDialog::SelectionTypeDialog(bool backupData, QWidget *parent)
     : QDialog(parent)
     , mSelectionTreeWidget(new SelectionTypeTreeWidget(backupData, this))
+    , mUseTemplateByDefault(new QCheckBox(i18n("Use this template by default"), this))
+    , mSaveTemplate(new QPushButton(i18n("Save as Template..."), this))
+    , mLoadTemplate(new QPushButton(i18n("Load Template..."), this))
 {
     setWindowTitle(i18nc("@title:window", "Select Type"));
     setModal(true);
@@ -37,12 +45,11 @@ SelectionTypeDialog::SelectionTypeDialog(bool backupData, QWidget *parent)
     mSelectionTreeWidget->setObjectName(QStringLiteral("mSelectionTreeWidget"));
     topLayout->addWidget(mSelectionTreeWidget);
 
-    mUseTemplateByDefault = new QCheckBox(i18n("Use this template by default"), this);
     mUseTemplateByDefault->setObjectName(QStringLiteral("mUseTemplateByDefault"));
     topLayout->addWidget(mUseTemplateByDefault);
 
     auto hbox = new QHBoxLayout;
-    QPushButton *selectAll = new QPushButton(i18n("Select All"), this);
+    auto selectAll = new QPushButton(i18n("Select All"), this);
     selectAll->setObjectName(QStringLiteral("selectAll"));
     connect(selectAll, &QPushButton::clicked, this, &SelectionTypeDialog::slotSelectAll);
     hbox->addWidget(selectAll);
@@ -52,12 +59,10 @@ SelectionTypeDialog::SelectionTypeDialog(bool backupData, QWidget *parent)
     connect(unselectAll, &QPushButton::clicked, this, &SelectionTypeDialog::slotUnselectAll);
     hbox->addWidget(unselectAll);
 
-    mSaveTemplate = new QPushButton(i18n("Save as Template..."), this);
     mSaveTemplate->setObjectName(QStringLiteral("mSaveTemplate"));
     connect(mSaveTemplate, &QPushButton::clicked, this, &SelectionTypeDialog::slotSaveAsTemplate);
     hbox->addWidget(mSaveTemplate);
 
-    mLoadTemplate = new QPushButton(i18n("Load Template..."), this);
     mLoadTemplate->setObjectName(QStringLiteral("mLoadTemplate"));
     connect(mLoadTemplate, &QPushButton::clicked, this, &SelectionTypeDialog::slotLoadTemplate);
     hbox->addWidget(mLoadTemplate);
@@ -73,23 +78,23 @@ SelectionTypeDialog::~SelectionTypeDialog()
     writeConfig();
 }
 
-void SelectionTypeDialog::writeConfig()
-{
-    KConfigGroup group(KSharedConfig::openStateConfig(), "SelectionTypeDialog");
-    group.writeEntry("Size", size());
-}
-
 void SelectionTypeDialog::readConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), "SelectionTypeDialog");
-    const QSize sizeDialog = group.readEntry("Size", QSize(600, 400));
-    if (sizeDialog.isValid()) {
-        resize(sizeDialog);
-    }
+    create(); // ensure a window is created
+    windowHandle()->resize(QSize(600, 400));
+    KConfigGroup group(KSharedConfig::openStateConfig(), myConfigSelectionTypeDialogDialog);
+    KWindowConfig::restoreWindowSize(windowHandle(), group);
+    resize(windowHandle()->size()); // workaround for QTBUG-40584
     loadDefaultTemplate();
 }
 
-QHash<Utils::AppsType, Utils::importExportParameters> SelectionTypeDialog::storedType() const
+void SelectionTypeDialog::writeConfig()
+{
+    KConfigGroup group(KSharedConfig::openStateConfig(), myConfigSelectionTypeDialogDialog);
+    KWindowConfig::saveWindowSize(windowHandle(), group);
+}
+
+QMap<Utils::AppsType, Utils::importExportParameters> SelectionTypeDialog::storedType() const
 {
     return mSelectionTreeWidget->storedType();
 }
