@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -42,12 +42,16 @@
 #include <QStatusBar>
 
 #include <dialog/pimdataexporterconfiguredialog.h>
-#include <kwidgetsaddons_version.h>
 #ifdef WITH_KUSERFEEDBACK
 #include "userfeedback/userfeedbackmanager.h"
+#ifdef USE_KUSERFEEDBACK_QT6
+#include <KUserFeedbackQt6/NotificationPopup>
+#include <KUserFeedbackQt6/Provider>
+#else
 #include <KUserFeedback/NotificationPopup>
 #include <KUserFeedback/Provider>
 #endif
+#endif
 
 PimDataExporterWindow::PimDataExporterWindow(QWidget *parent)
     : KXmlGuiWindow(parent)
@@ -354,20 +358,12 @@ void PimDataExporterWindow::slotRestoreData()
 
 void PimDataExporterWindow::loadData(const QString &filename, const QString &templateFile)
 {
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
     const int answer = KMessageBox::warningTwoActions(this,
-#else
-    const int answer = KMessageBox::warningYesNo(this,
-#endif
                                                       i18n("Before restoring data you must close all kdepim applications. Do you want to continue?"),
                                                       i18n("Backup"),
                                                       KStandardGuiItem::cont(),
                                                       KStandardGuiItem::cancel());
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
     if (answer == KMessageBox::ButtonCode::SecondaryAction) {
-#else
-    if (answer == KMessageBox::No) {
-#endif
         return;
     }
 
